@@ -4,9 +4,13 @@ from usefulpy.helpers import *
 import os
 
 class NewWWW(logic.BaseCommand):
-  signature = "new www <name> [(--user=user --group=group)] [--base=base] [--template=template] [--reload | --restart] [-D]"
-  def is_valid(self):
-    return self.arguments['new'] and self.arguments['www']
+  """
+  Usage:
+   useful.py www new <name> [(--user=user --group=group)] [--base=base] [--template=template] [--reload | --restart] [-D]
+
+  Options:
+    -D, --dry    Print the commands to stdout
+  """
 
   def run(self):
     runner = runners.BashRunner(self.arguments['--dry'])
